@@ -17,6 +17,7 @@ import aiofiles
 import aiohttp
 import click
 from aiohttp.client import ClientTimeout
+from click_help_colors import HelpColorsCommand
 from loguru import logger
 
 logger.remove()
@@ -24,7 +25,7 @@ logger.add(
     sys.stdout,
     format="<green>{time:YYYY-MM-DD HH:mm:ss.SSS}</green> | "
     "<level>{level: <8}</level> | "
-    "<cyan>{function}</cyan>:<cyan>{line}</cyan> - <level>{message}</level>",
+    "<cyan>asyncdown</cyan>:<cyan>{line}</cyan> - <level>{message}</level>",
     level="INFO",
     colorize=True,
 )
@@ -34,8 +35,8 @@ def check_exist(filename: str, url: str, urls: t.Dict[str, str]) -> None:
     """Check if the file exists in the local directory.
 
     .. note::
-                                    If the file exists, it will be overwritten.
-                                    If the file name starts with '#', it will be ignored.
+            If the file exists, it will be overwritten.
+            If the file name starts with '#', it will be ignored.
     """
     if Path(filename).exists():
         logger.warning(f"{filename} already exists, will be overwritten")
@@ -70,32 +71,115 @@ class WorkItem:
         self.output = output
 
 
+class Summary:
+    """Summary for the download process."""
+
+    def __init__(self, total: int = 0) -> None:
+        """Initialize the summary."""
+        self.total: int = total
+        self.success: int = 0
+        self.failed: int = 0
+        self.skipped: int = 0
+        self.failed_items: t.List[WorkItem] = []
+        self.is_updated_total = True if total == 0 else False
+
+    def __str__(self) -> str:
+        """Return the summary as a string."""
+        return (
+            f"Total: {self.total}, "
+            f"Success: {self.success}, "
+            f"Failed: {self.failed}, "
+            f"Skipped: {self.skipped}"
+        )
+
+    def write_failed_items(self, output) -> None:
+        """Write the failed items to the output file."""
+        if self.failed_items:
+            logger.info("Writing failed items to {}", output)
+            with open(output, "w") as f:
+                for item in self.failed_items:
+                    f.write(f"{item.output} {item.url}\n")
+
+    def update(self, work_item: WorkItem, success: bool, extra: str = "") -> None:
+        """Update the summary."""
+        if self.is_updated_total:
+            self.total += 1
+
+        if success:
+            self.success += 1
+            logger.success(f"Finished {work_item.output} {extra}")
+        else:
+            self.failed += 1
+            self.failed_items.append(work_item)
+            logger.error(f"Error downloading {work_item.output}: {extra}")
+
+    def progress(self):
+        """Print the progress."""
+        if not self.is_updated_total:
+            logger.info(
+                "Progress: {}/{} (success/total), {} failed, {} skipped",
+                self.success,
+                self.total,
+                self.failed,
+                self.skipped,
+            )
+        else:
+            logger.info(
+                "Progress: {} success, {} failed, {} skipped",
+                self.success,
+                self.failed,
+                self.skipped,
+            )
+
+    def summary(self):
+        """Print the summary."""
+        logger.info(
+            "Summary: Total: {},  Success: {}, Failed {}, Skipped {}",
+            self.total,
+            self.success,
+            self.failed,
+            self.skipped,
+        )
+
+    def reset(self):
+        """Reset the summary."""
+        self.total = 0
+        self.success = 0
+        self.failed = 0
+        self.skipped = 0
+        self.failed_items = []
+
+
 async def download(
-    url: str, local_filename: str, session: aiohttp.ClientSession
+    item: WorkItem, session: aiohttp.ClientSession, summary: Summary
 ) -> None:
     """Download a file from `url` and save it locally under `local_filename`."""
     try:
-        async with session.get(url) as resp:
+        async with session.get(item.url) as resp:
             if resp.status == 200:
-                async with aiofiles.open(local_filename, "wb") as f:
+                async with aiofiles.open(item.output, "wb") as f:
                     async for chunk in resp.content.iter_chunked(1024 * 1024):
                         await f.write(chunk)
             else:
                 raise RuntimeError(
-                    f"Cannot download {url} with status code {resp.status}"
+                    f"Cannot download {item.url} with status code {resp.status}"
                 )
     except Exception as e:
-        logger.error(f"Error downloading {local_filename}: {e}")
+        summary.update(item, False, str(e))
     else:
-        logger.success(f"Finished {local_filename}")
+        summary.update(item, True)
+    finally:
+        summary.progress()
 
 
-async def worker(worker_id: int, queue: Queue, session: aiohttp.ClientSession) -> None:
+async def worker(
+    worker_id: int, queue: Queue, session: aiohttp.ClientSession, summary: Summary
+) -> None:
     """Download the files in the urls asynchronously."""
     while True:
         item: WorkItem = await queue.get()
         logger.info(f"Worker {worker_id} Processing {item.output}")
-        await download(item.url, item.output, session)
+        await download(item, session, summary)
         queue.task_done()
 
 
@@ -113,23 +197,32 @@ def generate_work_items_blocking(urls: t.Dict[str, str], queue: Queue) -> None:
         queue.put_nowait(WorkItem(url, filename))
 
 
-async def main(urls: t.Dict[str, str], timeout: int, max_workers: int) -> None:
+async def main(
+    urls: t.Dict[str, str], timeout: int, max_workers: int, summary: Summary
+) -> None:
     """Download the files in the urls asynchronously."""
     queue: Queue = Queue()
     generate_work_items_blocking(urls, queue)
-    logger.info(f"Total Task: {queue.qsize()}")
 
     max_workers = min(max_workers, len(urls))
     logger.info(f"Starting {max_workers} workers")
 
     client_timeout = ClientTimeout(total=timeout)
     async with aiohttp.ClientSession(timeout=client_timeout) as session:
-        _ = [asyncio.create_task(worker(i, queue, session)) for i in range(max_workers)]
+        _ = [
+            asyncio.create_task(worker(i, queue, session, summary))
+            for i in range(max_workers)
+        ]
 
         await queue.join()
 
 
-@click.command(options_metavar="[options]")
+@click.command(
+    cls=HelpColorsCommand,
+    help_options_color="green",
+    help_headers_color="blue",
+    options_metavar="[options]",
+)
 @click.option("-u", "--url", type=click.STRING, metavar="<url>", help="URL to download")
 @click.option(
     "-o",
@@ -165,17 +258,26 @@ async def main(urls: t.Dict[str, str], timeout: int, max_workers: int) -> None:
     show_default=True,
     help="Maximum number of workers",
 )
-def cli(url: str, out: str, url_file: t.TextIO, time: int, workers: int) -> None:
+@click.option(
+    "--wf",
+    is_flag=True,
+    show_default=True,
+    default=False,
+    help="Write failed items to failed.txt",
+)
+def cli(
+    url: str, out: str, url_file: t.TextIO, time: int, workers: int, wf: bool
+) -> None:
     """Download files in terms of links asynchronously.
 
     \b
     Examples:
-                                    pybox asyncdown -u url-link  -o book.pdf
-                                    pybox asyncdown -f url-file.txt
+                    pybox asyncdown -u url-link  -o book.pdf
+                    pybox asyncdown -f url-file.txt
 
     \b
     Note:
-                                    1. If you want to download multiple files, you can use the url-file.
+                    1. If you want to download multiple files, you can use the url-file.
     """
     if not url and not url_file:
         raise click.BadArgumentUsage("You need to provide a url or a url file")
@@ -183,7 +285,12 @@ def cli(url: str, out: str, url_file: t.TextIO, time: int, workers: int) -> None
         raise click.BadArgumentUsage("You can only provide one url or url file")
 
     urls = {out: url} if url else read_urls(url_file)
-    asyncio.run(main(urls, time * 60, workers))
+    summary = Summary(total=len(urls))
+    asyncio.run(main(urls, time * 60, workers, summary))
+    if wf:
+        summary.write_failed_items("failed.txt")
+
+    summary.summary()
 
 
 if __name__ == "__main__":
